pub struct HealthCheck {
pub cmd: String,
pub interval: Option<String>,
pub timeout: Option<String>,
pub retries: Option<u32>,
pub start_period: Option<String>,
}Expand description
Health check configuration for a container
Fields
cmd: StringCommand to run for health check
interval: Option<String>Time between running the check (default: 30s)
timeout: Option<String>Maximum time to wait for a check to complete (default: 30s)
retries: Option<u32>Number of consecutive failures needed to consider unhealthy (default: 3)
start_period: Option<String>Start period for the container to initialize before counting retries (default: 0s)
Implementations
Sourceimpl HealthCheck
impl HealthCheck
Sourcepub fn with_interval(self, interval: &str) -> Self
pub fn with_interval(self, interval: &str) -> Self
Set the interval between health checks
Sourcepub fn with_timeout(self, timeout: &str) -> Self
pub fn with_timeout(self, timeout: &str) -> Self
Set the timeout for health checks
Sourcepub fn with_retries(self, retries: u32) -> Self
pub fn with_retries(self, retries: u32) -> Self
Set the number of retries for health checks
Sourcepub fn with_start_period(self, start_period: &str) -> Self
pub fn with_start_period(self, start_period: &str) -> Self
Set the start period for health checks